==> gnome-shell-extension-mediaplayer_3.2.orig.tar.gz: gnome-shell-extensions-mediaplayer-3.2/README.md <==
# gnome-shell-extensions-mediaplayer

gnome-shell-extensions-mediaplayer is a gnome-shell extension for controlling
any MPRIS v2.1 capable media player.

## Please see the Wiki for:
  * [Contributing](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Contributing)
  * [Bug Reports and Feature Requests](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Bug-Reports-and-Feature-Requests)
  * [Installation](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Installation)
  * [Settings](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Settings)
  * [Compatible Players](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Compatible-players)
  * [Ratings Support](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Ratings-Support)
  * [Known Player Bugs](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Known-Player-Bugs)

## Screenshot

![Screenshot](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/raw/master/data/screenshot.png)

## Features

- 3 positions: center or right in its own menu, or in the system menu
- interactive indicator icon: scroll (next/previous), middle click (play/pause)
- playlist support (org.mpris.MediaPlayer2.Playlists interface)
- tracklist support (org.mpris.MediaPlayer2.TrackList interface)
- Shuffle and Repeat support(not well supported by players. Lollypop has full support)
- rating support (Not a part of the MPRIS spec, limited support with player specifc code, see [Ratings Support](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Ratings-Support). Currently you can set ratings in Rhythmbox, Lollypop, Nuvola Player, Quod Libet and Pithos.)
- and more...

## Authors

  * eonpatapon (Jean-Philippe Braun)
  * grawity (Mantas Mikulėnas)
  * JasonLG1979 (Jason Gray)

Based on the work of horazont (Jonas Wielicki).

[![License: GPL v2](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)

## Like this Extension?

Then maybe consider donating to help continue it's development, otherwise known as buying me a RedBull.

You don't have to, but it would be cool if you did.

[![Flattr this git repo](https://api.flattr.com/button/flattr-badge-large.png)](https://flattr.com/submit/auto?user_id=JasonLG1979&url=https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer)

And/or consider donating to one of these other projects I believe in.

[GNOME](https://www.gnome.org/support-gnome/donate/)

[The Free Software Foundation](https://www.fsf.org/about/ways-to-donate/)

[The Electronic Frontier Foundation](https://supporters.eff.org/donate/)

==> gnome-shell-extension-mediaplayer_3.5.orig.tar.gz: gnome-shell-extensions-mediaplayer-3.5/README.md <==
# gnome-shell-extensions-mediaplayer

gnome-shell-extensions-mediaplayer is a gnome-shell extension for controlling
any MPRIS v2.1 capable media player.

## Please see the Wiki for:
  * [Contributing](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Contributing)
  * [Bug Reports and Feature Requests](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Bug-Reports-and-Feature-Requests)
  * [Installation](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Installation)
  * [Settings](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Settings)
  * [Compatible Players](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Compatible-players)
  * [Ratings Support](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Ratings-Support)
  * [Known Player Bugs](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Known-Player-Bugs)

## Screenshot

![Screenshot](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/raw/master/data/screenshot.png)

## Features

- 4 positions: left, center or right in its own menu, or in the system menu
- interactive indicator icon: scroll (next/previous), middle click (play/pause)
- playlist support (org.mpris.MediaPlayer2.Playlists interface)
- tracklist support (org.mpris.MediaPlayer2.TrackList interface)
- Shuffle and Repeat support(not well supported by players. Lollypop has full support)
- rating support (Not a part of the MPRIS spec, limited support with player specifc code, see [Ratings Support](https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer/wiki/Ratings-Support). Currently you can set ratings in Rhythmbox, Lollypop, Nuvola Player, Quod Libet and Pithos.)
- and more...

## Authors

  * eonpatapon (Jean-Philippe Braun)
  * grawity (Mantas Mikulėnas)
  * JasonLG1979 (Jason Gray)

Based on the work of horazont (Jonas Wielicki).

[![License: GPL v2](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)

## Like this Extension?

Then maybe consider donating to help continue it's development, otherwise known as buying me a RedBull.

You don't have to, but it would be cool if you did.

[![Flattr this git repo](https://api.flattr.com/button/flattr-badge-large.png)](https://flattr.com/submit/auto?user_id=JasonLG1979&url=https://github.com/JasonLG1979/gnome-shell-extensions-mediaplayer)

And/or consider donating to one of these other projects I believe in.

[GNOME](https://www.gnome.org/support-gnome/donate/)

[The Free Software Foundation](https://www.fsf.org/about/ways-to-donate/)

[The Electronic Frontier Foundation](https://supporters.eff.org/donate/)
